Response

Struct Response 

pub struct Response(/* private fields */);

Implementations

Source

impl Response

pub fn new(body: Vec<u8>) -> Self

pub fn from_parts( status: u16, headers: HashMap<String, String>, body: Vec<u8>, ) -> Result<Self>

pub fn to_parts(&self) -> (u16, HashMap<String, String>, Vec<u8>)

pub fn into_inner(self) -> Response<Vec<u8>>

pub fn into_body(self) -> Vec<u8>

Methods from Deref<Target = Response<Vec<u8>>>

pub fn status(&self) -> StatusCode

Returns the StatusCode.

Examples
let response: Response<()> = Response::default();
assert_eq!(response.status(), StatusCode::OK);
pub fn status_mut(&mut self) -> &mut StatusCode

Returns a mutable reference to the associated StatusCode.

Examples
let mut response: Response<()> = Response::default();
*response.status_mut() = StatusCode::CREATED;
assert_eq!(response.status(), StatusCode::CREATED);
pub fn version(&self) -> Version

Returns a reference to the associated version.

Examples
let response: Response<()> = Response::default();
assert_eq!(response.version(), Version::HTTP_11);
pub fn version_mut(&mut self) -> &mut Version

Returns a mutable reference to the associated version.

Examples
let mut response: Response<()> = Response::default();
*response.version_mut() = Version::HTTP_2;
assert_eq!(response.version(), Version::HTTP_2);
pub fn headers(&self) -> &HeaderMap

Returns a reference to the associated header field map.

Examples
let response: Response<()> = Response::default();
assert!(response.headers().is_empty());
pub fn headers_mut(&mut self) -> &mut HeaderMap

Returns a mutable reference to the associated header field map.

Examples
let mut response: Response<()> = Response::default();
response.headers_mut().insert(HOST, HeaderValue::from_static("world"));
assert!(!response.headers().is_empty());
pub fn extensions(&self) -> &Extensions

Returns a reference to the associated extensions.

Examples
let response: Response<()> = Response::default();
assert!(response.extensions().get::<i32>().is_none());
pub fn extensions_mut(&mut self) -> &mut Extensions

Returns a mutable reference to the associated extensions.

Examples
let mut response: Response<()> = Response::default();
response.extensions_mut().insert("hello");
assert_eq!(response.extensions().get(), Some(&"hello"));
pub fn body(&self) -> &T

Returns a reference to the associated HTTP body.

Examples
let response: Response<String> = Response::default();
assert!(response.body().is_empty());
pub fn body_mut(&mut self) -> &mut T

Returns a mutable reference to the associated HTTP body.

Examples
let mut response: Response<String> = Response::default();
response.body_mut().push_str("hello world");
assert!(!response.body().is_empty());