pub async fn serve_application(
listener: ListenerConfig,
application: ApplicationFetch,
max_body_bytes: usize,
shutdown: CancellationToken,
) -> Result<()>Expand description
Bind a TCP listener that forwards every request to an application handler.
This listener is independent of the serverless runtime and can run beside a normal serverful envoy using the same registry shutdown token.